@@ -109,7 +109,7 @@ static void ical_export_valarm(FILE * stream)
 {
 	fputs("BEGIN:VALARM\n", stream);
 	pthread_mutex_lock(&nbar.mutex);
-	fprintf(stream, "TRIGGER:-P%dS\n", nbar.cntdwn);
+	fprintf(stream, "TRIGGER:-PT%dS\n", nbar.cntdwn);
 	pthread_mutex_unlock(&nbar.mutex);
 	fputs("ACTION:DISPLAY\n", stream);
 	fputs("END:VALARM\n", stream);
@@ -214,7 +214,8 @@ static void ical_export_note(FILE *stream, char *name)
 
 	asprintf(&note_file, "%s/%s", path_notes, name);
 	if (!(fp = fopen(note_file, "r")) || ungetc(getc(fp), fp) == EOF) {
-		fclose(fp);
+		if (fp)
+			fclose(fp);
 		return;
 	}
 	string_init(&note);
@@ -690,7 +691,7 @@ static int ical_readline(FILE * fdi, char *buf, char *lstore, unsigned *ln)
 	while (fgets(lstore, BUFSIZ, fdi) != NULL) {
 		(*ln)++;
 		if ((eol = strchr(lstore, '\n')) != NULL) {
-			if (*(eol - 1) == '\r')
+			if (strlen(lstore) > 1 && *(eol - 1) == '\r')
 				*(eol - 1) = '\0';
 			else
 				*eol = '\0';
@@ -1447,7 +1448,7 @@ ical_read_event(FILE * fdi, FILE * log, unsigned *noevents,
 					 _("malformed event end time."));
 				goto skip;
 			}
-			if (vevent.end <= vevent.start) {
+			if (vevent.end < vevent.start) {
 				ical_log(log, ICAL_VEVENT, ITEMLINE,
 					 _("end must be later than start."));
 				goto skip;
